import React, { useEffect, useState } from 'react'
import {
	Box,
	Button,
	Divider,
	makeStyles,
	Card,
	Typography,
	CardHeader,
	CardActions,
	CardContent,
	TextField
} from '@material-ui/core'
import { useHistory } from 'react-router-dom'

const useStyles = makeStyles(theme => ({
	root: {
		display: 'flex',
		flexDirection: 'column',
		alignItems: 'center',
		justifyContent: 'center',
		height: '100vh',
		backgroundColor: theme.palette.background.default
	},
	card: {
		display: 'flex',
		flexDirection: 'column',
		alignItems: 'center',
		justifyContent: 'center',
		padding: '0px 30px',
		minHeight: '20vh'
	},
	actions: {
		justifyContent: 'center'
	}
}))

export default function Confirmacion() {
	const classes = useStyles()
	const [ intervalId, setIntervalId ] = useState(-1)
	const [ codigo, setCodigo ] = useState('')
	const [ { min, seg }, setRestante ] = useState({ min: 0, seg: 0 })

	const history = useHistory()

	const calcularRestante = limite => {
		const res = limite.getTime() - new Date().getTime()
		setRestante({ min: Math.floor(res / 1000 / 60), seg: Math.round((res / 1000) % 60) })
	}

	useEffect(
		() => {
			reenviar()
		},
		// eslint-disable-next-line react-hooks/exhaustive-deps
		[]
	)

	if (seg <= 0 && min <= 0) clearInterval(intervalId)

	const validar = () => {
        if (codigo) history.push('/finalizado')
	}

	const reenviar = () => {
		clearInterval(intervalId)
		const ahora = new Date()
		ahora.setMinutes(new Date().getMinutes() + 5)
		console.log(ahora)
		calcularRestante(ahora)
		setIntervalId(setInterval(() => calcularRestante(ahora), 1000))
	}

	return (
		<Box className={classes.root}>
			<Card>
				<CardHeader
					disableTypography
					title={
						<Typography variant='h5' align='center'>
							Validar correo
						</Typography>
					}
				/>
				<Divider />
				<CardContent>
					<Typography paragraph variant='h6'>
						Para finalizar con el registro, ingrese el codigo que recibió en su casilla de correo
					</Typography>
					<TextField
						name='codigo'
						value={codigo}
						onChange={({ target: { value } }) => setCodigo(value)}
                        variant='outlined'
                        fullWidth
                        label='Codigo de confirmacion'
                        margin='normal'
					/>
				</CardContent>
				<Divider />
				<CardActions className={classes.actions}>
					<Button variant='contained' color='primary' onClick={reenviar} disabled={seg > 0 || min > 0}>
						{seg > 0 || min > 0 ? (
							`Reenviar (${min < 10 ? '0' : ''}${min}:${seg < 10 ? '0' : ''}${seg})`
						) : (
							'Reenviar'
						)}
					</Button>
					<Button variant='contained' color='primary' onClick={validar} disabled={!codigo}>
						Validar
					</Button>
				</CardActions>
			</Card>
		</Box>
	)
}
