import React, { useState } from 'react'
import {
	Box,
	Button,
	Divider,
	makeStyles,
	Card,
	Typography,
	CardHeader,
	CardActions,
	CardContent,
	TextField
} from '@material-ui/core'
import { useHistory } from 'react-router-dom'

const useStyles = makeStyles(theme => ({
	root: {
		display: 'flex',
		flexDirection: 'column',
		alignItems: 'center',
		justifyContent: 'center',
		height: '100vh',
		backgroundColor: theme.palette.background.default
	},
	card: {
		display: 'flex',
		flexDirection: 'column',
		alignItems: 'center',
		justifyContent: 'center',
		padding: '0px 30px',
		minHeight: '20vh',
		minWidth: '20vw'
	},
	actions: {
		justifyContent: 'center'
	}
}))

export default function Formulario() {
	const classes = useStyles()
	const [ { nombre, apellido, mail, confirmar, error, codigoInvalido, codigo }, setState ] = useState({
		confirmar: false,
		codigo: '',
		nombre: '',
		apellido: '',
		mail: '',
		error: false,
		codigoInvalido: false
	})

	const history = useHistory()

	const mailValido = () => mail.indexOf('@') !== -1 && mail.indexOf('.') !== -1

	const siguiente = () => {
		if (nombre && apellido && mailValido() && codigo) {
			//put con los datos y ver si el colegio es valido, si no lo es, volver al formulario e indicar el error
			//poner en el storage el estado de pendiente
			setState(ps => ({ ...ps, confirmar: true }))
		} else setState(ps => ({ ...ps, error: true }))
	}

	const enviar = () => {
		history.push('/pendiente')
	}

	const fields = [
		{
			name: 'nombre',
			value: nombre,
			label: 'Nombre'
		},
		{
			name: 'apellido',
			value: apellido,
			label: 'Apellido'
		},
		{
			name: 'mail',
			value: mail,
			label: 'Correo',
			error: error && !mailValido()
		},
		{
			name: 'codigo',
			value: codigo,
			label: 'Codigo de colegio',
			error: (error && !codigo) || codigoInvalido
		}
	]

	return (
		<Box className={classes.root}>
			<Card>
				<CardHeader
					disableTypography
					title={
						<Typography variant='h5' align='center'>
							{confirmar ? 'Confirmar datos' : 'Formulario'}
						</Typography>
					}
				/>
				<Divider />
				<CardContent className={classes.card}>
					{confirmar ? (
						fields.map((field, i) => (
							<Typography key={'ty-' + i} paragraph>
								{field.label}: {field.value}
							</Typography>
						))
					) : (
						fields.map((field, i) => (
							<TextField
								key={'tf' + i}
								error={error && !field.value}
								{...field}
								margin='normal'
								fullWidth
								required
								variant='outlined'
								onChange={({ target: { name, value } }) => setState(ps => ({ ...ps, [name]: value }))}
							/>
						))
					)}
				</CardContent>
				<Divider />
				<CardActions className={classes.actions}>
					<Button variant='contained' color='primary' onClick={confirmar ? enviar : siguiente}>
						{confirmar ? 'Enviar' : 'Siguiente'}
					</Button>
				</CardActions>
			</Card>
		</Box>
	)
}
